#!/bin/bash 

usb=$1
size=$2
part=`echo $usb`1
rsync="rsync --delete -rvtDW --progress --modify-window=1"
ventoy="./ventoy/Ventoy2Disk.sh"

if [ -z $usb -o -z $size ]
then
  echo "Usage: sudo ./prepare-usb.sh <device> <size>"
  exit 1
fi

if [ $size -eq 16 -o $size -eq 32 ]
then
  echo "Working with $size GB disk..."
else
  echo "Usage: sudo ./prepare-usb.sh <device> <size>"
  echo "       <size> should be 16 or 32"
  exit 1
fi

if [ $UID -gt 0 ]
then
  echo "Please run as root."
  echo "Usage: sudo ./prepare-usb.sh <device>"
  exit 1
fi

OS_FOR_16GB_DEB="
  DEBIAN/debian-12.1.0-amd64-netinst.iso*
  DEBIAN/debian-12.1.0-amd64-DVD-1.iso*
"
OS_FOR_16GB_OTH="
  OTHER/znetboot.xyz.img*
  OTHER/proxmox-ve_8.0-2.iso*
  OTHER/systemrescue-9.05-amd64.iso*
  OTHER/tails-amd64-5.16.img*
  OTHER/ubuntu-23.04-desktop-amd64.iso*
  OTHER/yunohost-bullseye-11.0.9-amd64-stable.iso*
  OTHER/zarchcraft-2023.07.05-x86_64.iso*
"

OS_FOR_32GB_DEBIAN="
  DEBIAN/debian-12.1.0-amd64-netinst.iso*
  DEBIAN/debian-12.1.0-amd64-DVD-1.iso* 
  DEBIAN/debian-live-12.1.0-amd64-kde.iso*
  DEBIAN/debian-live-12.1.0-amd64-gnome.iso*
"
OS_FOR_32GB_OTHER="
  OTHER/yunohost-bullseye-11.0.9-amd64-stable.iso*
  OTHER/znetboot.xyz.img*
  OTHER/proxmox-ve_8.0-2.iso*
  OTHER/systemrescue-9.05-amd64.iso*
  OTHER/tails-amd64-5.16.img*
  OTHER/trisquel_11.0_amd64.iso*
  OTHER/ubuntu-23.04-desktop-amd64.iso*
  OTHER/devuan_daedalus_5.0.0_amd64_desktop-live.iso*
 "

RPi="
  2022-09-22-raspios-bullseye-arm64-lite.img.xz
  2022-09-22-raspios-bullseye-armhf-lite.img.xz
"

TOOLS="
  balenaEtcher-1.7.9-x64.AppImage
  balenaEtcher-Setup-1.7.9.exe
  ungoogled-chromium_107.0.5304.68-1.1.AppImage
"

## Install Ventoy
if [ $size -eq 16 ]
then
  $ventoy -i /dev/$usb -L MH-USB -I -g
  sleep 20
  OS_DEB=$OS_FOR_16GB_DEB
  OS_OTH=$OS_FOR_16GB_OTH
else
  $ventoy -i /dev/$usb -L MH-USB -I -g
  sleep 20
  OS_DEB=$OS_FOR_32GB_DEBIAN
  OS_OTH=$OS_FOR_32GB_OTHER 
fi

## Copy ISOs
mkdir -p /mnt/mhusb/
mount /dev/$part /mnt/mhusb
mkdir -p /mnt/mhusb/OS/DEBIAN
mkdir -p /mnt/mhusb/OS/OTHER
mkdir -p /mnt/mhusb/Tools
mkdir -p /mnt/mhusb/ventoy

cd MH-USB/OS/
time $rsync $OS_DEB /mnt/mhusb/OS/DEBIAN
time $rsync $OS_OTH /mnt/mhusb/OS/OTHER

cd ../Tools/
time $rsync $TOOLS /mnt/mhusb/Tools/

cd ../
time $rsync ventoy/ /mnt/mhusb/ventoy

#if [ $size -eq 32 ]
#then
#  cd RPi/
#  mkdir -p /mnt/mhusb/RPi/
#  $rsync $RPi /mnt/mhusb/RPi/
#fi

echo "Done."

